@@ -6,7 +6,6 @@ from indy_client.test.agent.test_walleted_agent import TestWalletedAgent
 from indy_common.strict_types import strict_types
 from stp_core.network.port_dispenser import genHa
 
-
 strict_types.defaultShouldCheck = True
 
 # def pytest_configure(config):
@@ -40,8 +39,7 @@ from indy_node.test.helper import addAttributeAndCheck
 from indy_client.test.helper import createNym, TestClient
 
 # noinspection PyUnresolvedReferences
-from indy_node.test.conftest import nodeSet, updatedDomainTxnFile, \
-    genesisTxns
+from indy_node.test.conftest import nodeSet, genesisTxns
 
 # noinspection PyUnresolvedReferences
 from plenum.test.conftest import poolTxnStewardData, poolTxnStewardNames
@@ -59,6 +57,7 @@ def walletBuilder():
         wallet = Wallet(name)
         wallet.addIdentifier(signer=DidSigner())
         return wallet
+
     return _
 
 
@@ -99,6 +98,7 @@ def agentBuilder(tdirWithClientPoolTxns):
                               port=port)
 
         return agent
+
     return _
 
 
