@@ -200,7 +200,7 @@ def prompt_is(prompt):
     return x
 
 
-def addTxnToGenesisFile(dir, file, txns, fields=getTxnOrderedFields()):
+def addTxnsToGenesisFile(dir, file, txns, fields=getTxnOrderedFields()):
     ledger = create_genesis_txn_init_ledger(dir, file)
     for txn in txns:
         ledger.add(txn)
@@ -220,7 +220,7 @@ def addTrusteeTxnsToGenesis(trusteeList, trusteeData, txnDir, txnFileName):
             except StopIteration as e:
                 logger.debug(
                     '{} not found in trusteeData'.format(trusteeToAdd))
-        addTxnToGenesisFile(txnDir, txnFileName, txns)
+        addTxnsToGenesisFile(txnDir, txnFileName, txns)
     return added
 
 
