@@ -47,7 +47,7 @@ def test_add_same_node_with_changed_bls_by_trustee(be, do, trusteeCli,
     '''
     be(trusteeCli)
     node_vals = newNodeVals
-    node_vals['newNodeData'][BLS_KEY] = base58.b58encode(randomString(128).encode())
+    node_vals['newNodeData'][BLS_KEY] = base58.b58encode(randomString(128).encode()).decode("utf-8")
     doSendNodeCmd(do, node_vals,
                   expMsgs=["TRUSTEE not in allowed roles ['STEWARD']"])
     exitFromCli(do)
@@ -108,7 +108,7 @@ def test_update_bls(be, do, newStewardCli,
 
     node_vals = nodeValsEmptyData
     node_vals['newNodeData'][ALIAS] = newNodeVals['newNodeData'][ALIAS]
-    node_vals['newNodeData'][BLS_KEY] = base58.b58encode(randomString(128).encode())
+    node_vals['newNodeData'][BLS_KEY] = base58.b58encode(randomString(128).encode()).decode("utf-8")
 
     doSendNodeCmd(do, node_vals,
                   expMsgs=['Node request completed'])
@@ -125,7 +125,7 @@ def test_update_bls_by_trustee(be, do, trusteeCli,
 
     node_vals = nodeValsEmptyData
     node_vals['newNodeData'][ALIAS] = newNodeVals['newNodeData'][ALIAS]
-    node_vals['newNodeData'][BLS_KEY] = base58.b58encode(randomString(128).encode())
+    node_vals['newNodeData'][BLS_KEY] = base58.b58encode(randomString(128).encode()).decode("utf-8")
 
     doSendNodeCmd(do, node_vals,
                   expMsgs=["TRUSTEE not in allowed roles ['STEWARD']"])
