@@ -24,4 +24,4 @@ def test_node_upgrade_scheduled_on_proper_date(poolNodesStarted,
     # Verify that the upgrade is scheduled in approximately 5 days for each node
     now = datetime.utcnow().replace(tzinfo=dateutil.tz.tzutc())
     for node in poolNodesStarted.nodes.values():
-        assert (node.upgrader.scheduledUpgrade[1] - now).days == 5
+        assert (node.upgrader.scheduledAction[1] - now).days == 5
