@@ -16,6 +16,7 @@ ATTRIBUTES = "attributes"
 ATTR_NAMES = "attr_names"
 ACTION = 'action'
 SCHEDULE = 'schedule'
+DATETIME = 'datetime'
 TIMEOUT = 'timeout'
 SHA256 = 'sha256'
 START = 'start'
@@ -68,6 +69,10 @@ REVOCATION = "revocation"
 
 WRITES = "writes"
 
+RESTART_MESSAGE = "restart"
+UPGRADE_MESSAGE = "upgrade"
+MESSAGE_TYPE = "message_type"
+
 allOpKeys = (
     TXN_TYPE,
     TARGET_NYM,
@@ -102,6 +107,7 @@ ENDPOINT = "endpoint"
 
 # Roles
 TRUST_ANCHOR = Roles.TRUST_ANCHOR.value
+TRUST_ANCHOR_STRING = 'TRUST_ANCHOR'
 TGB = Roles.TGB.value
 
 # client transaction types
@@ -124,6 +130,8 @@ GET_REVOC_REG_DELTA = IndyTransactions.GET_REVOC_REG_DELTA.value
 
 POOL_UPGRADE = IndyTransactions.POOL_UPGRADE.value
 NODE_UPGRADE = IndyTransactions.NODE_UPGRADE.value
+POOL_RESTART = IndyTransactions.POOL_RESTART.value
+VALIDATOR_INFO = IndyTransactions.VALIDATOR_INFO.value
 
 POOL_CONFIG = IndyTransactions.POOL_CONFIG.value
 
@@ -138,7 +146,7 @@ fields = {NYM: ([TARGET_NYM], [ROLE]),
           REVOC_REG_ENTRY: ([REVOC_REG_DEF_ID, TYPE, VALUE]),
           }
 
-CONFIG_TXN_TYPES = {POOL_UPGRADE, NODE_UPGRADE, POOL_CONFIG}
+CONFIG_TXN_TYPES = {POOL_UPGRADE, NODE_UPGRADE, POOL_CONFIG, POOL_RESTART}
 IDENTITY_TXN_TYPES = {NYM,
                       ATTRIB,
                       DISCLO,
