@@ -10,27 +10,31 @@ from plenum.common.messages.message_base import MessageValidator
 from plenum.common.request import Request as PRequest
 from plenum.common.types import OPERATION
 from plenum.common.messages.node_messages import NonNegativeNumberField
-from plenum.common.messages.fields import ConstantField, IdentifierField, LimitedLengthStringField, TxnSeqNoField, \
-    Sha256HexField, JsonField, MapField, BooleanField, VersionField, ChooseField, IntegerField, IterableField, \
-    AnyMapField, NonEmptyStringField
+from plenum.common.messages.fields import ConstantField, IdentifierField, \
+    LimitedLengthStringField, TxnSeqNoField, \
+    Sha256HexField, JsonField, MapField, BooleanField, VersionField, \
+    ChooseField, IntegerField, IterableField, \
+    AnyMapField, NonEmptyStringField, DatetimeStringField
 from plenum.common.messages.client_request import ClientOperationField as PClientOperationField
 from plenum.common.messages.client_request import ClientMessageValidator as PClientMessageValidator
 from plenum.common.util import is_network_ip_address_valid, is_network_port_valid
 from plenum.config import JSON_FIELD_LIMIT, NAME_FIELD_LIMIT, DATA_FIELD_LIMIT, \
     NONCE_FIELD_LIMIT, ORIGIN_FIELD_LIMIT, \
     ENC_FIELD_LIMIT, RAW_FIELD_LIMIT, SIGNATURE_TYPE_FIELD_LIMIT, \
-    HASH_FIELD_LIMIT, VERSION_FIELD_LIMIT
+    HASH_FIELD_LIMIT, VERSION_FIELD_LIMIT, DATETIME_LIMIT
 
 from indy_common.constants import TXN_TYPE, allOpKeys, ATTRIB, GET_ATTR, \
     DATA, GET_NYM, reqOpKeys, GET_TXNS, GET_SCHEMA, GET_CLAIM_DEF, ACTION, \
     NODE_UPGRADE, COMPLETE, FAIL, CONFIG_LEDGER_ID, POOL_UPGRADE, POOL_CONFIG, \
-    DISCLO, ATTR_NAMES, REVOCATION, SCHEMA, ENDPOINT, CLAIM_DEF, REF, SIGNATURE_TYPE, SCHEDULE, SHA256, \
-    TIMEOUT, JUSTIFICATION, JUSTIFICATION_MAX_SIZE, REINSTALL, WRITES, PRIMARY, START, CANCEL, \
+    DISCLO, ATTR_NAMES, REVOCATION, SCHEMA, ENDPOINT, CLAIM_DEF, REF, \
+    SIGNATURE_TYPE, SCHEDULE, SHA256, \
+    TIMEOUT, JUSTIFICATION, JUSTIFICATION_MAX_SIZE, REINSTALL, WRITES, PRIMARY, \
+    START, CANCEL, \
     REVOC_REG_DEF, ISSUANCE_TYPE, MAX_CRED_NUM, PUBLIC_KEYS, \
     TAILS_HASH, TAILS_LOCATION, ID, REVOC_TYPE, TAG, CRED_DEF_ID, VALUE, \
     REVOC_REG_ENTRY, ISSUED, REVOC_REG_DEF_ID, REVOKED, ACCUM, PREV_ACCUM, \
     GET_REVOC_REG_DEF, GET_REVOC_REG, TIMESTAMP, \
-    GET_REVOC_REG_DELTA, FROM, TO
+    GET_REVOC_REG_DELTA, FROM, TO, POOL_RESTART, DATETIME, VALIDATOR_INFO
 
 
 class Request(PRequest):
@@ -274,6 +278,21 @@ class ClientPoolUpgradeOperation(MessageValidator):
     )
 
 
+class ClientPoolRestartOperation(MessageValidator):
+    schema = (
+        (TXN_TYPE, ConstantField(POOL_RESTART)),
+        (ACTION, ChooseField(values=(START, CANCEL,))),
+        (DATETIME, DatetimeStringField(exceptional_values=["0", ""],
+                                       optional=True)),
+    )
+
+
+class ClientValidatorInfoOperation(MessageValidator):
+    schema = (
+        (TXN_TYPE, ConstantField(VALIDATOR_INFO)),
+    )
+
+
 class ClientPoolConfigOperation(MessageValidator):
     schema = (
         (TXN_TYPE, ConstantField(POOL_CONFIG)),
@@ -295,6 +314,8 @@ class ClientOperationField(PClientOperationField):
         GET_SCHEMA: ClientGetSchemaOperation(),
         POOL_UPGRADE: ClientPoolUpgradeOperation(),
         POOL_CONFIG: ClientPoolConfigOperation(),
+        POOL_RESTART: ClientPoolRestartOperation(),
+        VALIDATOR_INFO: ClientValidatorInfoOperation(),
         REVOC_REG_DEF: ClientRevocDefSubmitField(),
         REVOC_REG_ENTRY: ClientRevocRegEntrySubmitField(),
         GET_REVOC_REG_DEF: ClientGetRevocRegDefField(),
