@@ -1,25 +1,20 @@
 from plenum.common.constants import DOMAIN_LEDGER_ID
-from plenum.common.types import f
 from plenum.common.util import randomString
-from plenum.test.helper import assertLength
 from plenum.test.node_catchup.helper import checkNodeDataForEquality, \
     waitNodeDataEquality
+from plenum.test.pool_transactions.helper import sdk_add_new_nym
 from plenum.test.test_node import ensure_node_disconnected, checkNodesConnected
-from indy_client.test.client.TestClient import TestClient
-from indy_client.test.helper import getClientAddedWithRole
-from indy_common.constants import TRUST_ANCHOR
-from indy_node.test.conftest import nodeThetaAdded
-from indy_node.test.helper import TestNode, addRawAttribute, getAttribute
+from indy_node.test.conftest import sdk_node_theta_added
+from indy_node.test.helper import TestNode, sdk_add_raw_attribute
 from indy_common.config_helper import NodeConfigHelper
 
 
-def test_new_node_catchup_update_projection(looper, tdirWithClientPoolTxns,
-                                            tdirWithDomainTxnsUpdated,
+def test_new_node_catchup_update_projection(looper,
                                             nodeSet, tconf, tdir,
-                                            trustee, trusteeWallet,
+                                            sdk_pool_handle,
+                                            sdk_wallet_trustee,
                                             allPluginsPath,
-                                            some_transactions_done
-                                            ):
+                                            some_transactions_done):
     """
     A node which receives txns from catchup updates both ledger and projection
     4 nodes start up and some txns happen, after txns are done, new node joins
@@ -29,21 +24,20 @@ def test_new_node_catchup_update_projection(looper, tdirWithClientPoolTxns,
     """
     # Create a new node and stop it.
 
-    new_steward, new_steward_wallet, new_node = nodeThetaAdded(looper,
-                                                               nodeSet,
-                                                               tdirWithClientPoolTxns,
-                                                               tconf, trustee,
-                                                               trusteeWallet,
-                                                               allPluginsPath,
-                                                               TestNode,
-                                                               TestClient,
-                                                               NodeConfigHelper,
-                                                               tdir)
+    new_steward_wallet, new_node = sdk_node_theta_added(looper,
+                                                        nodeSet,
+                                                        tdir,
+                                                        tconf,
+                                                        sdk_pool_handle,
+                                                        sdk_wallet_trustee,
+                                                        allPluginsPath,
+                                                        node_config_helper_class=NodeConfigHelper,
+                                                        testNodeClass=TestNode)
 
     waitNodeDataEquality(looper, new_node, *nodeSet[:-1])
     ta_count = 2
     np_count = 2
-    new_txn_count = 2 * ta_count + np_count   # Since ATTRIB txn is done for TA
+    new_txn_count = 2 * ta_count + np_count  # Since ATTRIB txn is done for TA
     old_ledger_sizes = {}
     new_ledger_sizes = {}
     old_projection_sizes = {}
@@ -70,11 +64,11 @@ def test_new_node_catchup_update_projection(looper, tdirWithClientPoolTxns,
     def check_sizes(nodes):
         for node in nodes:
             assert new_ledger_sizes[node.name] - \
-                old_ledger_sizes[node.name] == new_txn_count
+                   old_ledger_sizes[node.name] == new_txn_count
             assert new_projection_sizes[node.name] - \
-                old_projection_sizes[node.name] == new_txn_count
+                   old_projection_sizes[node.name] == new_txn_count
             assert new_seq_no_map_sizes[node.name] - \
-                old_seq_no_map_sizes[node.name] == new_txn_count
+                   old_seq_no_map_sizes[node.name] == new_txn_count
 
     # Stop a node and note down the sizes of ledger and projection (state)
     other_nodes = nodeSet[:-1]
@@ -89,29 +83,16 @@ def test_new_node_catchup_update_projection(looper, tdirWithClientPoolTxns,
     attributes = []
     for i in range(ta_count):
         trust_anchors.append(
-            getClientAddedWithRole(
-                other_nodes,
-                tdirWithClientPoolTxns,
-                looper,
-                trustee,
-                trusteeWallet,
-                'TA' + str(i),
-                role=TRUST_ANCHOR,
-                client_connects_to=len(other_nodes)))
+            sdk_add_new_nym(looper, sdk_pool_handle, sdk_wallet_trustee,
+                            role='TRUST_ANCHOR', alias='TA' + str(i)))
         attributes.append((randomString(6), randomString(10)))
-        addRawAttribute(looper, *trust_anchors[-1], *attributes[-1],
-                        dest=trust_anchors[-1][1].defaultId)
+        sdk_add_raw_attribute(looper, sdk_pool_handle, trust_anchors[-1],
+                              *attributes[-1])
     non_privileged = []
     for i in range(np_count):
         non_privileged.append(
-            getClientAddedWithRole(
-                other_nodes,
-                tdirWithClientPoolTxns,
-                looper,
-                trustee,
-                trusteeWallet,
-                'NP' + str(i),
-                client_connects_to=len(other_nodes)))
+            sdk_add_new_nym(looper, sdk_pool_handle, sdk_wallet_trustee,
+                            alias='NP' + str(i)))
 
     checkNodeDataForEquality(nodeSet[0], *other_nodes)
     fill_counters(new_ledger_sizes, new_projection_sizes, new_seq_no_map_sizes,
@@ -137,28 +118,15 @@ def test_new_node_catchup_update_projection(looper, tdirWithClientPoolTxns,
                   [new_node])
     check_sizes([new_node])
 
-    for i, (tc, tw) in enumerate(trust_anchors):
-        # To prevent sending of 'get_attr' to just one node
-        tc._read_only_requests = set()
-
-        reply = getAttribute(looper, tc, tw, tw.defaultId, *attributes[i])
-        all_replies = tc.getRepliesFromAllNodes(reply[f.IDENTIFIER.nm],
-                                                reply[f.REQ_ID.nm])
-        assertLength(all_replies, len(nodeSet))
-        assert new_node.clientstack.name in all_replies
-
     # Set the old counters to be current ledger and projection size
     fill_counters(old_ledger_sizes, old_projection_sizes, old_seq_no_map_sizes,
                   nodeSet)
 
     more_nyms_count = 2
-    for tc, tw in trust_anchors:
+    for wh in trust_anchors:
         for i in range(more_nyms_count):
-            non_privileged.append(getClientAddedWithRole(other_nodes,
-                                                         tdirWithClientPoolTxns,
-                                                         looper,
-                                                         tc, tw,
-                                                         'NP1' + str(i)))
+            non_privileged.append(sdk_add_new_nym(looper, sdk_pool_handle, wh,
+                                                  alias='NP1' + str(i)))
 
     # The new node should process transactions done by Nyms added to its
     # ledger while catchup
