@@ -4,20 +4,19 @@ from plenum.common.constants import DOMAIN_LEDGER_ID
 from plenum.common.util import randomString
 from plenum.test.node_catchup.helper import ensure_all_nodes_have_same_data, \
     waitNodeDataEquality
+from plenum.test.pool_transactions.helper import sdk_add_new_nym
 from plenum.test.test_node import checkNodesConnected, ensure_node_disconnected
-from indy_client.test.helper import getClientAddedWithRole
-from indy_common.constants import TRUST_ANCHOR
+from indy_common.constants import TRUST_ANCHOR_STRING
 from indy_common.config_helper import NodeConfigHelper
-from indy_node.test.helper import addRawAttribute, TestNode
-
+from indy_node.test.helper import TestNode, sdk_add_raw_attribute
 
 TestRunningTimeLimitSec = 200
 
 
-def test_state_regenerated_from_ledger(looper, tdirWithClientPoolTxns,
-                                       tdirWithDomainTxnsUpdated,
+def test_state_regenerated_from_ledger(looper,
                                        nodeSet, tconf, tdir,
-                                       trustee, trusteeWallet,
+                                       sdk_pool_handle,
+                                       sdk_wallet_trustee,
                                        allPluginsPath):
     """
     Node loses its state database but recreates it from ledger after start.
@@ -25,21 +24,19 @@ def test_state_regenerated_from_ledger(looper, tdirWithClientPoolTxns,
     """
     trust_anchors = []
     for i in range(5):
-        trust_anchors.append(getClientAddedWithRole(nodeSet,
-                                                    tdirWithClientPoolTxns, looper,
-                                                    trustee, trusteeWallet,
-                                                    'TA' + str(i),
-                                                    role=TRUST_ANCHOR))
-        addRawAttribute(looper, *trust_anchors[-1], randomString(6),
-                        randomString(10), dest=trust_anchors[-1][1].defaultId)
+        trust_anchors.append(sdk_add_new_nym(looper, sdk_pool_handle,
+                                             sdk_wallet_trustee,
+                                             'TA' + str(i),
+                                             TRUST_ANCHOR_STRING))
+        sdk_add_raw_attribute(looper, sdk_pool_handle,
+                              trust_anchors[-1],
+                              randomString(6),
+                              randomString(10))
 
-    for tc, tw in trust_anchors:
+    for wh in trust_anchors:
         for i in range(3):
-            getClientAddedWithRole(nodeSet,
-                                   tdirWithClientPoolTxns,
-                                   looper,
-                                   tc, tw,
-                                   'NP1' + str(i))
+            sdk_add_new_nym(looper, sdk_pool_handle,
+                            wh, 'NP1' + str(i))
 
     ensure_all_nodes_have_same_data(looper, nodeSet)
 
@@ -71,11 +68,8 @@ def test_state_regenerated_from_ledger(looper, tdirWithClientPoolTxns,
     waitNodeDataEquality(looper, restarted_node, *nodeSet[:-1])
 
     # Pool is still functional
-    for tc, tw in trust_anchors:
-        getClientAddedWithRole(nodeSet,
-                               tdirWithClientPoolTxns,
-                               looper,
-                               tc, tw,
-                               'NP--{}'.format(tc.name))
+    for wh in trust_anchors:
+        sdk_add_new_nym(looper, sdk_pool_handle,
+                        wh, 'NP--' + randomString(5))
 
     ensure_all_nodes_have_same_data(looper, nodeSet)
