@@ -1,14 +1,12 @@
 from copy import deepcopy
 
-import pytest
-
 from indy_node.test import waits
 from stp_core.loop.eventually import eventually
 from plenum.common.constants import VERSION
 from indy_common.constants import FORCE
 
 from indy_node.test.upgrade.helper import bumpedVersion, checkUpgradeScheduled, \
-    ensureUpgradeSent, check_no_loop
+    check_no_loop, sdk_ensure_upgrade_sent
 from indy_node.server.upgrade_log import UpgradeLog
 import indy_node
 
@@ -16,15 +14,15 @@ whitelist = ['Failed to upgrade node']
 
 
 def test_upgrade_does_not_get_into_loop_force(looper, tconf, nodeSet,
-                                              validUpgrade, trustee,
-                                              trusteeWallet, monkeypatch):
+                                              validUpgrade, sdk_pool_handle,
+                                              sdk_wallet_trustee, monkeypatch):
     new_version = bumpedVersion()
     upgr1 = deepcopy(validUpgrade)
     upgr1[VERSION] = new_version
     upgr1[FORCE] = True
 
     # An upgrade scheduled, it should pass
-    ensureUpgradeSent(looper, trustee, trusteeWallet, upgr1)
+    sdk_ensure_upgrade_sent(looper, sdk_pool_handle, sdk_wallet_trustee, upgr1)
     looper.run(
         eventually(
             checkUpgradeScheduled,
@@ -35,4 +33,4 @@ def test_upgrade_does_not_get_into_loop_force(looper, tconf, nodeSet,
 
     # here we make nodes think they have upgraded successfully
     monkeypatch.setattr(indy_node.__metadata__, '__version__', new_version)
-    check_no_loop(nodeSet, UpgradeLog.UPGRADE_SUCCEEDED)
+    check_no_loop(nodeSet, UpgradeLog.SUCCEEDED)
