@@ -1,4 +1,3 @@
-import pytest
 from stp_core.loop.eventually import eventually
 from indy_node.server.upgrader import Upgrader
 import functools
@@ -37,10 +36,13 @@ def testTimeoutWorks(nodeSet, looper, monkeypatch):
     for node in nodeSet:
         monkeypatch.setattr(
             node.upgrader,
-            '_upgradeFailedCallback',
+            '_actionFailedCallback',
             functools.partial(
                 upgrade_failed_callback_test,
                 node.name))
-        looper.run(node.upgrader._sendUpdateRequest(when, version, None, timeout))
+        looper.run(node.upgrader._sendUpgradeRequest(when,
+                                                     version,
+                                                     None,
+                                                     timeout))
 
     looper.run(eventually(chk))
